Learn R Programming

spatial.gev.bma (version 1.0)

g.prime: The first derivative of the posterior density of a spatial GEV model with respect to a given random effect on the precision parameter.

Description

This returns the first derivative of the posterior density of a spatial GEV model with respect to a random effect on the precision parameter. It is used in forming the Metropolis-Hastings update of this parameter.

Usage

g.prime(tau, tau.hat, varsigma, xi, kappa.hat, eps)

Arguments

tau
Current value of the random effect
tau.hat
The conditional mean of the random effect given the others and the current Gaussian process parameters.
varsigma
The conditional variance of the random effect based on the Gaussian process parameters
xi
The current shape parameter for this location
kappa.hat
The linear part of the precision parameters
eps
The vector of residuals based on the observations at this site and the associated location parmeter

Value

A scalar giving the first derivative, which is used to form the Metropolis-Hasting update.