Learn R Programming

spatial.gev.bma (version 1.0)

gev.crps: Compute the Continuous Rank Probability Score (CRPS)

Description

This takes a large sample from a predictive distribution and computes the CRPS for a number of observations. It is used in judging the fit of predictive distributions.

Usage

gev.crps(Y.obs, Y.samp)

Arguments

Y.obs
A vector of observed values
Y.samp
A large sample from the posterior predictive distribution.

Value

A scalar giving the CRPS