Learn R Programming

spatial.gev.bma (version 1.0)

gev.like: The log likelihood of a GEV distribution

Description

Returns the log likelihood of a GEV distribution accoding to the parameterization used in spatial.gev.bma

Usage

gev.like(Y, mu, kappa, xi)

Arguments

Y
The outcome at which the log likelihood should be evaluated
mu
The location parameter
kappa
The precision parameter
xi
The shape parameter

Value

A scalar giving the log-likelihood