Learn R Programming

spatial.gev.bma (version 1.0)

gev.logscore: Compute the Log Score

Description

This takes a large sample from a predictive distribution and computes the log score for a vector of observations, judging the fit of predictive distributions.

Usage

gev.logscore(Y.obs, Y.samp)

Arguments

Y.obs
A vector of observed values
Y.samp
A large sample from the posterior predictive distribution.

Value

A scalar giving the mean log score over the observations