Learn R Programming

spatial.gev.bma (version 1.0)

gev.process.results: Outputs some tables from the results of Spatial GEV MCMC run

Description

This take the output from a spatial GEV run and returns some handy tables given posterior probabilities, effective sample sizes, acceptance probabilities, etc.

Usage

gev.process.results(R, burn = 100)

Arguments

R
The output from the spatial.gev.bma function
burn
An optional burn-in amount to be discarded before forming results.

Value

Returns a number of tables.