Learn R Programming

spatial.gev.bma (version 1.0)

gev.update.M: Sample a new model from the current model for any linear regression system

Description

This uses a conditional Bayes factor (CBF) to update a model in a linear system given a current model and other information in a spatial GEV model. Note that it is agnostic to which part of the framework (location, precision, scale) you are updating.

Usage

gev.update.M(Y, X, M, alpha, lambda, D, beta.0, Omega.0)

Arguments

Y
The current dependent variable, calculated relative to the linear plus random effect terms of the given component.
X
The matrix of covariates
M
The current model. A subset of (1, ..., p) where p is the number of columns in X
alpha
The precision term of the Gaussian process for this component of the model
lambda
The length term of the Gaussian process for this component of the model
D
The distance matrix used in the Gaussian process
beta.0
The prior mean on the linear regression terms
Omega.0
The prior covariance on the linear regression terms

Value

This returns an updated model, which is a vector that is a subset of (1, ..., p).