Learn R Programming

spatial.gev.bma (version 1.0)

gev.update.tau.kappa: Update the random effects of the precision parameter in a spatial GEV model

Description

This goes through and updates, via M-H, each component in the random effects of a spatial GEV model

Usage

gev.update.tau.kappa(G)

Arguments

G
The current state of a spatial GEV model

Value

A new state of the spatial GEV model where the random effects have been updated