Learn R Programming

spatial.gev.bma (version 1.0)

gev.update.tau.xi: Update the random effects for the shape parameter in a spatial GEV model

Description

This goes through the random effects in the shape parameter of a hierarchical spatial GEV model and updates them individually using focused Metropolis-Hastings proposals.

Usage

gev.update.tau.xi(G)

Arguments

G
The current state of the model

Value

A new state of the model where the random effects have been updated.