Learn R Programming

spatial.gev.bma (version 1.0)

gev.update.theta: Update the linear parameters in a spatial GEV model

Description

This internal function updates the linear regression terms of a given component of a spatial GEV model. Due to blocking, the method is agnostic to which component it is updating

Usage

gev.update.theta(Y, X, M, alpha, lambda, D, beta.0, Omega.0)

Arguments

Y
The dependent valuesn

X
The matrix of covariates

M
The current model for this component

alpha
The overall variance of the GP

lambda
The scale of the GP

D
The distance matrix of the GP

beta.0
The prior mean for the covariates

Omega.0
The prior precision for the covariates

Value

Returns a new set of linear regression terms