Learn R Programming

spatial.gev.bma (version 1.0)

norway: Extreme Precipitation Data at 69 Sites in Norway

Description

This dataset provides observations of extreme precipitation in Norway at 69 sites, along with covariate information.

Usage

data(norway)

Arguments

Format

A list containing three objects. Y.list is itself a list, with the observations at each site. X is a matrix with the coviates and S is a matrix with their relative position