Learn R Programming

spatial.gev.bma (version 1.0)

spatial.gev.bma-package: Fit a Hierarchical Spatial Generalized Extreme Value model that allows for Bayesian Model Averaging

Description

This package allows one to fit a hierarhical spatial model for extremes. It enables linear specifications in all three GEV parameters and incorporates Bayesian Model Averaging to account for model uncertainty. Further, it uses recent results in automatic proposal formation of Metropolis-Hastings samplers to avoid requiring the user to have to specify a large number of tuning parameters.

Arguments

Details

Package:
spatial.gev.bma
Type:
Package
Version:
1.0
Date:
2014-03-11
License:
GPL

References

A. Dyrrdal, A. Lenkoski, T. Thorarinsdottir, F. Stordal (2014). Bayesian hierarchical modeling of extreme hourly precipitation in Norway. arxiv:1309.6111