g.double.prime: The second derivative of a GEV distribution with respect to a
random effect parameter on the precision kappa
Description
This function returns the second derivative of a GEV
distribution with respect to the random effect tau_s^kappa.
It is used in forming the proposal for the Metropolis-Hastings update
of this parameter.
Usage
g.double.prime(tau, tau.hat, varsigma, xi, kappa.hat, eps)
Arguments
tau
The current value of the random effect
tau.hat
The conditional fitted value of the random effect given
the others according to the Gaussian Process
varsigma
The conditional variance of the fitted value according to the
Gaussian Process
xi
The current value of the shape parameter
kappa.hat
This is the linear bit of the precision for this location
eps
The vector of residuals for this site, i.e. Y_ts - mu_s
Value
A scalar giving the second derivative