gev.impute: Given the output of the MCMC, return a number of samples for a new site.
Description
This takes the object returned from spatial.gev.bma and new
information for a given site and returns a large sample of values
from the posterior predictive distribution for that site.