Arguments
Y
The current dependent variable, calculated relative to the linear
plus random effect terms of the given component.
X
The matrix of covariates
M
The current model. A subset of (1, ..., p) where p is the number of
columns in X
alpha
The precision term of the Gaussian process for this component of the model
lambda
The length term of the Gaussian process for this component of the model
D
The distance matrix used in the Gaussian process
beta.0
The prior mean on the linear regression terms
Omega.0
The prior covariance on the linear regression terms