Rdocumentation
powered by
Learn R Programming
spatial.gev.bma (version 1.0)
gev.update.tau.mu: Internal function to update the random effects of the location parameter in a Spatial GEV model.
Description
This internal function takes the state of a Spatial GEV model, and updates the random effects for the location parameter
Usage
gev.update.tau.mu(G)
Arguments
G
An object holding the current state information for a Spatial GEV model
Value
An updated state for use in the Spatial GEV model.