j.prime: The first derivative of the posterior density of a spatial GEV
model with respect to a random effect parameter on the shape.
Description
This internal function calculates the first derivative of a
spatial GEV model with respect to a random effect parameter on the
shape and is used during the Metropolis-Hastings update of this
parameter conditional on everything else.Usage
j.prime(tau, tau.hat, varsigma, kappa, xi.hat, eps)
Arguments
tau
Current value of the random effect
tau.hat
Conditional mean of the random effect given all others and the
Gaussian process parameters.
varsigma
Conditional variance of the random effect according to the Gaussian process
kappa
Current value for the GEV scale at this site.
xi.hat
Current linear part of the GEV shape at this site.
eps
Vector of residuals for observations of this site given the current
location value.
Value
A scalar giving the first derivative of this density