l.double.prime: The second derivative of a Gaussian process with respect to the
parameter lambda.
Description
This utility returns the value of the second derivative of
the posterior of lambda in a Gaussian process. It is used to make a
focused M-H proposal when updating the lambda parameter.
Usage
l.double.prime(tau, alpha, lambda, D, a, b)
Arguments
tau
The vector of current random effects.
alpha
The current state of the precision of the Gaussian process
lambda
The current state of lambda
D
The distance matrix of the relevant entries in tau
a
The prior parameter for lambda
b
The second prior parameter for lambda
Value
This returns a scalar that is then used in the focused update. Its a
pretty internal function.